@@ -11,13 +11,13 @@ Lexical::Types - Extend the semantics of typed lexicals.
 
 =head1 VERSION
 
-Version 0.14
+Version 0.15
 
 =cut
 
 our $VERSION;
 BEGIN {
- $VERSION = '0.14';
+ $VERSION = '0.15';
 }
 
 =head1 SYNOPSIS
@@ -164,9 +164,9 @@ sub import {
  }
 
  $^H |= 0x020000;
- # Yes, we store a coderef inside the hints hash, but that's just for compile
- # time.
  $^H{+(__PACKAGE__)} = $hint;
+
+ return;
 }
 
 =head2 C<unimport>
@@ -179,7 +179,10 @@ Turns the pragma off.
 =cut
 
 sub unimport {
+ $^H |= 0x020000;
  $^H{+(__PACKAGE__)} = undef;
+
+ return;
 }
 
 =head1 RUN-TIME INITIALIZER METHOD
@@ -310,8 +313,6 @@ You can find documentation for this module with the perldoc command.
 
     perldoc Lexical::Types
 
-Tests code coverage report is available at L<http://www.profvince.com/perl/cover/Lexical-Types>.
-
 =head1 ACKNOWLEDGEMENTS
 
 Inspired by Ricardo Signes.
